<?php

/*
Pterodactyl®
Copyright © Dane Everitt <dane@daneeveritt.com> and contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

namespace Convoy\Console\Commands\User;

use Exception;
use Convoy\Models\User;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Hash;
use Convoy\Exceptions\Model\DataValidationException;

class MakeUserCommand extends Command
{
    protected $description = 'Creates a user on the system via the CLI.';

    protected $signature = 'c:user:make {--email=} {--name=} {--password=} {--admin=}';

    /**
     * Handle command request to create a new user.
     *
     * @throws Exception
     * @throws DataValidationException
     */
    public function handle(): void
    {
        $root_admin = $this->option('admin') ?? $this->confirm('Is this user an administrator?');
        $email = $this->option('email') ?? $this->ask('Email Address');
        $name = $this->option('name') ?? $this->ask('Name');
        $password = $this->option('password') ?? $this->secret('Password');

        $user = User::create([
            'name' => $name,
            'email' => $email,
            'root_admin' => (bool) $root_admin,
            'password' => Hash::make($password),
        ]);

        $this->table(['Field', 'Value'], [
            ['Internal ID', $user->id],
            ['Email', $user->email],
            ['Name', $user->name],
            ['Admin', $user->root_admin ? 'Yes' : 'No'],
        ]);
    }
}
